# Changelog

## 0.2.0 (2025-07-28)

Full Changelog: [v0.1.0...v0.2.0](https://github.com/nextbillion-ai/nextbillion-sdk-python/compare/v0.1.0...v0.2.0)

### Features

* **api:** update via SDK Studio ([beea33b](https://github.com/nextbillion-ai/nextbillion-sdk-python/commit/beea33b0e166caee6359fdd40fa4d94073be0e1e))
* **api:** update via SDK Studio ([ee67913](https://github.com/nextbillion-ai/nextbillion-sdk-python/commit/ee67913fd64767c8e79ac7af3c8ad3ac85da92fe))

## 0.1.0 (2025-07-28)

Full Changelog: [v0.1.0-alpha.2...v0.1.0](https://github.com/nextbillion-ai/nextbillion-sdk-python/compare/v0.1.0-alpha.2...v0.1.0)

### Features

* **api:** update via SDK Studio ([da9cfa8](https://github.com/nextbillion-ai/nextbillion-sdk-python/commit/da9cfa87ba2121209f66f7ef25f3e863bf147da7))
* **api:** update via SDK Studio ([f781a68](https://github.com/nextbillion-ai/nextbillion-sdk-python/commit/f781a68a66acf68b2d5cdd1698f0856e6b35dfae))
* **api:** update via SDK Studio ([91e5e03](https://github.com/nextbillion-ai/nextbillion-sdk-python/commit/91e5e03cb19ee39d96607e598e70b0799fb60c87))


### Chores

* update SDK settings ([40eeb25](https://github.com/nextbillion-ai/nextbillion-sdk-python/commit/40eeb25fb398c97eba062957bfca9e9883d163f6))
* update SDK settings ([ee2bfcb](https://github.com/nextbillion-ai/nextbillion-sdk-python/commit/ee2bfcb9f1926c490d13393c9e3683c3d11e1b6d))

## 0.1.0-alpha.2 (2025-07-28)

Full Changelog: [v0.1.0-alpha.1...v0.1.0-alpha.2](https://github.com/nextbillion-ai/nextbillion-sdk-python/compare/v0.1.0-alpha.1...v0.1.0-alpha.2)

### Features

* **api:** update via SDK Studio ([bfa9f1e](https://github.com/nextbillion-ai/nextbillion-sdk-python/commit/bfa9f1e2268d60eef0186e7a369e76e1c892d45c))

## 0.1.0-alpha.1 (2025-07-28)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/nextbillion-ai/nextbillion-sdk-python/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** update via SDK Studio ([7db4de0](https://github.com/nextbillion-ai/nextbillion-sdk-python/commit/7db4de05d06d2e0b4d9a2cb5d936a8d594fbd45e))
* **api:** update via SDK Studio ([af4a4e1](https://github.com/nextbillion-ai/nextbillion-sdk-python/commit/af4a4e1dcb35063fe690209d09488a3bcbbf6f2a))
* **api:** update via SDK Studio ([2d7d7b2](https://github.com/nextbillion-ai/nextbillion-sdk-python/commit/2d7d7b2544ecd70b6c3f1e74c8c5f4760527da24))
* **api:** update via SDK Studio ([9e69da0](https://github.com/nextbillion-ai/nextbillion-sdk-python/commit/9e69da05cb56954600f26c7efdce4112d41bb982))
* **api:** update via SDK Studio ([ec30966](https://github.com/nextbillion-ai/nextbillion-sdk-python/commit/ec30966e6cefe4e47042eacb31245d78823097ac))
* **api:** update via SDK Studio ([8f9817b](https://github.com/nextbillion-ai/nextbillion-sdk-python/commit/8f9817b249e2c335388eea2b207b2aec073aa483))
* **api:** update via SDK Studio ([1a58313](https://github.com/nextbillion-ai/nextbillion-sdk-python/commit/1a58313f88a98541eecda1f732051f3ed3cf9985))
* **api:** update via SDK Studio ([5274652](https://github.com/nextbillion-ai/nextbillion-sdk-python/commit/52746522fe2999bf34af34c00fac0067bbf5f497))
* **api:** update via SDK Studio ([795ae31](https://github.com/nextbillion-ai/nextbillion-sdk-python/commit/795ae3119cec0b342a22d793438a53f6302106d8))
* **api:** update via SDK Studio ([d638858](https://github.com/nextbillion-ai/nextbillion-sdk-python/commit/d6388586d5b849960b556a1ef17befe104af10e8))
* **api:** update via SDK Studio ([0ee4915](https://github.com/nextbillion-ai/nextbillion-sdk-python/commit/0ee4915c4fa9356adfe99abdf4fce1f77cdb515f))
* **api:** update via SDK Studio ([501e44a](https://github.com/nextbillion-ai/nextbillion-sdk-python/commit/501e44ad9e7a7dac6ef6815d44749bbfd251520b))
* **api:** update via SDK Studio ([213f8e0](https://github.com/nextbillion-ai/nextbillion-sdk-python/commit/213f8e058c7bbd97aaa536d01090ae5a6fa49cc4))
* **api:** update via SDK Studio ([4a032b3](https://github.com/nextbillion-ai/nextbillion-sdk-python/commit/4a032b347dcf068449f7e950ff9dda83899ff59d))
* **api:** update via SDK Studio ([adb122b](https://github.com/nextbillion-ai/nextbillion-sdk-python/commit/adb122b947a235f8775404a7f852c0d91015dff3))
* **api:** update via SDK Studio ([8340bcf](https://github.com/nextbillion-ai/nextbillion-sdk-python/commit/8340bcf8e4ba9b769f79788bf77ec50529825e1e))


### Chores

* configure new SDK language ([336b505](https://github.com/nextbillion-ai/nextbillion-sdk-python/commit/336b505ae05e26842d3fdd2518c253001bc21d02))
* update SDK settings ([268b92d](https://github.com/nextbillion-ai/nextbillion-sdk-python/commit/268b92dcc2db9bb16f7e777b4a1c4b1bedad965b))
* update SDK settings ([a92aee8](https://github.com/nextbillion-ai/nextbillion-sdk-python/commit/a92aee8914855da3fa259d31e81de56291c536a0))
